%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Gittins Bandit Player.
%
% (c) 2014 Pedro A. Ortega <pedro.ortega@gmail.com>
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Action, Reward, Prob] = gittinsRun(theta, T)

%% Configuration.
gittinsFile = 'gittins.txt';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Load indices.
persistent gittins
if isempty(gittins)
    gittins = dlmread(gittinsFile);
end

%% Initialize.
s = [0, 0];
f = [0, 0];

Action = zeros(1, T);
Reward = zeros(1, T);
Prob   = zeros(1, T);

%% Execute one run.
for t=1:T
    % Choose action.
    gIdx = [gittins(f(1)+1, s(1)+1), gittins(f(2)+1, s(2)+1)];
    [maxVal, action] = max(gIdx);

    % Pull lever.
    reward = rand <= theta(action);

    % Update.
    s(action) = s(action) + reward;
    f(action) = f(action) + 1 - reward;

    % Record.
    Action(t) = (action == 1);
    Reward(t) = reward;
    Prob(t)   = 1.0 * theta(action);
end

