%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Thompson Sampling Bandit Player.
%
% (c) 2014 Pedro A. Ortega <pedro.ortega@gmail.com>
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Action, Reward, Prob] = thompsonRun(theta, T)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Initialize.
s = [0, 0];
f = [0, 0];

Action = zeros(1, T);
Reward = zeros(1, T);
Prob   = zeros(1, T);

%% Execute one run.
for t=1:T
    % Choose action.
    theta_hat = [betarnd(s(1)+1, f(1)+1), betarnd(s(2)+1,f(2)+1)];
    [maxVal, action] = max(theta_hat);

    % Pull lever.
    reward = rand <= theta(action);

    % Update.
    s(action) = s(action) + reward;
    f(action) = f(action) + 1 - reward;

    % Record.
    Action(t) = (action == 1);
    Reward(t) = reward;
    Prob(t)   = 1.0 * theta(action);
end

