%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% UCB1 Bandit Player.
%
% (c) 2014 Pedro A. Ortega <pedro.ortega@gmail.com>
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Action, Reward, Prob] = ucb1Run(theta, T)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Initialize.
s = [0, 0];
n = [1, 1];

Action = zeros(1, T);
Reward = zeros(1, T);
Prob   = zeros(1, T);

%% Execute one run.
for t=1:T
    % Choose action.
    ucb = s./n + sqrt(2*log(t)./n);
    [maxVal, action] = max(ucb);

    % Pull lever.
    reward = rand <= theta(action);

    % Update.
    s(action) = s(action) + reward;
    n(action) = n(action) + 1;

    % Record.
    Action(t) = (action == 1);
    Reward(t) = reward;
    Prob(t)   = 1.0 * theta(action);
end

